==> haskell-aeson-diff-1.1.0.5-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-diff
version: 1.1.0.5
id: aeson-diff-1.1.0.5-KLz7MEtsZhKFeGLkuRNI27
key: aeson-diff-1.1.0.5-KLz7MEtsZhKFeGLkuRNI27
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/aeson-diff
synopsis: Extract and apply patches to JSON documents.
description:
    .
    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.
    .
category: JSON, Web, Algorithms
abi: 8b724ee88091a9b6a060f371a4871938
exposed: True
exposed-modules:
    Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-diff-1.1.0.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-diff-1.1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/aeson-diff-1.1.0.5
hs-libraries: HSaeson-diff-1.1.0.5-KLz7MEtsZhKFeGLkuRNI27
depends:
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl base-4.12.0.0
    bytestring-0.10.8.2
    edit-distance-vector-1.0.0.4-5QalLWx3XsH57Wk3J1CdcP
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html: /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-diff-1.1.0.5-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-diff
version: 1.1.0.5
id: aeson-diff-1.1.0.5-5fnFYnEG9nY4y2uo84ynrO
key: aeson-diff-1.1.0.5-5fnFYnEG9nY4y2uo84ynrO
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/aeson-diff
synopsis: Extract and apply patches to JSON documents.
description:
    .
    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.
    .
category: JSON, Web, Algorithms
abi: d518b7725cf291c238715e3cf3af50da
exposed: True
exposed-modules:
    Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-diff-1.1.0.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-diff-1.1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/aeson-diff-1.1.0.5
hs-libraries: HSaeson-diff-1.1.0.5-5fnFYnEG9nY4y2uo84ynrO
depends:
    aeson-1.4.2.0-3Fy8y4TZyLW38WYgCKr7yc base-4.12.0.0
    bytestring-0.10.8.2
    edit-distance-vector-1.0.0.4-BEOrCqAjMhfIEDxZ8gqnif
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html: /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
